@@ -7,7 +7,7 @@ confint.glm <- function(object, parm, level = 0.95, trace = FALSE, ...)
     pnames <- names(coef(object))
     if(missing(parm)) parm <- seq_along(pnames)
     else if(is.character(parm))  parm <- match(parm, pnames, nomatch = 0)
-    cat("Waiting for profiling to be done...\n")
+    message("Waiting for profiling to be done...")
     flush.console()
     object <- profile(object, which = parm, alpha = (1. - level)/4.,
                       trace = trace)
@@ -42,7 +42,7 @@ confint.nls <-
   pnames <- names(coef(object))
   if(missing(parm)) parm <- seq_along(pnames)
   if(is.numeric(parm))  parm <- pnames[parm]
-  cat("Waiting for profiling to be done...\n")
+  message("Waiting for profiling to be done...")
   flush.console()
   object <- profile(object, which = parm, alphamax = (1. - level)/4.)
   confint(object, parm=parm, level=level, ...)
