@@ -66,6 +66,8 @@ lda.default <-
 {
     if(is.null(dim(x))) stop("'x' is not a matrix")
     x <- as.matrix(x)
+    if(any(!is.finite(x)))
+        stop("infinite, NA or NaN values in 'x'")
     n <- nrow(x)
     p <- ncol(x)
     if(n != length(grouping))
@@ -99,8 +101,8 @@ lda.default <-
     if(any(f1 < tol)) {
         const <- format((1:p)[f1 < tol])
         stop(sprintf(ngettext(length(const),
-                     "variable %d appears to be constant within groups",
-                     "variables %d appear to be constant within groups"),
+                     "variable %s appears to be constant within groups",
+                     "variables %s appear to be constant within groups"),
                      paste(const, collapse = " ")),
              domain = NA)
     }
@@ -283,7 +285,7 @@ print.lda <- function(x, ...)
     if(!is.null(cl <- x$call)) {
         names(cl)[2] <- ""
         cat("Call:\n")
-        dput(cl)
+        dput(cl, control=NULL)
     }
     cat("\nPrior probabilities of groups:\n")
     print(x$prior, ...)
