@@ -1,6 +1,6 @@
 .noGenerics <- TRUE
 
-.onAttach <- function(...) require(stats)
+.onAttach <- function(...) require("stats")
 
 .onUnload <- function(libpath)
     library.dynam.unload("MASS", libpath)
